@@ -5,6 +5,10 @@ pub use elfo_macros::{message, msg};
 
 #[cfg(feature = "elfo-configurer")]
 pub use elfo_configurer as configurer;
+#[cfg(feature = "elfo-logger")]
+pub use elfo_logger as logger;
+#[cfg(feature = "test-util")]
+pub use elfo_test as test;
 
 pub mod prelude {
     pub use super::{assert_msg, assert_msg_eq, message, msg, ActorGroup, Context, Schema};
@@ -15,6 +19,3 @@ pub mod actors {
     #[cfg(feature = "elfo-configurer")]
     pub use super::configurer;
 }
-
-#[cfg(feature = "test-util")]
-pub use elfo_test as test;
